IThemeModeManager class abstract

Interface to be implemented in order to load and save the selected ThemeMode.

Constructors

IThemeModeManager()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

loadThemeMode() → Future<String?>
Loads the selected ThemeMode as a String.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveThemeMode(String value) → Future<bool>
Allows the consumer to save the selected ThemeMode as a String.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited